Crate namada_vp_env

Crate namada_vp_env 

Validity predicate environment contains functions that can be called from inside validity predicates.

Modules

collection_validation
Storage change validation helpers

Structs

BlockHeader
The block header data from Tendermint header relevant for Namada storage
BlockHeight
Height of a block, i.e. the level. The default is the BlockHeight::sentinel value, which doesn’t correspond to any block.
Epoch
Epoch identifier. Epochs are identified by consecutive numbers.
Epochs
Predecessor block epochs
Key
A storage key is made of storage key segments DbKeySeg, separated by KEY_SEGMENT_SEPARATOR.
TxIndex
Transaction index within block.

Enums

Error

Traits

StorageRead
Common storage read interface
VpEnv
Validity predicate’s environment is available for native VPs and WASM VPs

Type Aliases

Result
Result of a storage API call.